# vim: set ts=4 sw=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           atop
Version:        2.2
%define pkg_version %{version}-3
Release:        lp151.2.3
Summary:        Monitor for System Resources and Process Activity
Source:         http://www.atoptool.nl/download/atop-%{pkg_version}.tar.gz
Source1:        atop.desktop
Source99:       atop-rpmlintrc
Patch1:         atop-makefile.patch
URL:            http://www.atoptool.nl/
Group:          System/Monitoring
License:        GPL-2.0
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  ncurses-devel make glibc-devel gcc
BuildRequires:  zlib-devel
BuildRequires:  systemd-rpm-macros
%if 0%{?suse_version:1}
BuildRequires:  update-desktop-files
%endif
%{?systemd_requires}

%description
Atop is an ASCII full-screen performance monitor, similar to the top
command. At regular intervals, it shows system-level activity related to
the CPU, memory, swap, disks and network layers, and it shows for every
active process the CPU utilization in system and user mode, the virtual
and resident memory growth, priority, username, state, and exit code. The
process level activity is also shown for processes which finished during
the last interval, to get a complete overview about the consumers of things
such as CPU time. Atop only shows the active system-resources and processes,
and only shows the deviations since the previous interval.

%package daemon
Summary:        System Resource and Process Monitoring History Daemon
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
Recommends:     logrotate
Recommends:     cron

%description daemon
Atop is an ASCII full-screen performance monitor, similar to the top
command. At regular intervals, it shows system-level activity related to
the CPU, memory, swap, disks and network layers, and it shows for every
active process the CPU utilization in system and user mode, the virtual
and resident memory growth, priority, username, state, and exit code. The
process level activity is also shown for processes which finished during
the last interval, to get a complete overview about the consumers of things
such as CPU time. Atop only shows the active system-resources and processes,
and only shows the deviations since the previous interval.

This subpackage contains the permanent monitoring daemon, to store history
information about processes and system resources.

%prep
%setup -q -n "%{name}-%{pkg_version}"
%patch1

%build
%__make %{?_smp_mflags} \
    	  OPTFLAGS="%{optflags} -fstack-protector" \
    	  CC="%__cc" \
    	  INIPATH=/etc/init.d

%install
%__install -d "%{buildroot}%{_sbindir}"
make systemdinstall DESTDIR=%{buildroot}

%__rm -f "%{buildroot}%{_localstatedir}/log/atop"/*

%__install -D -m0644 "atop.service" "%{buildroot}%{_usr}/lib/systemd/system/%{name}.service"

%__install -D -m 0644 atop.cronsystemd "%{buildroot}/etc/cron.d/%{name}"

%__install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%if 0%{?suse_update_desktop_file:1}
%suse_update_desktop_file -r "%{name}" System Monitor
%endif

ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcatopacct

%pre daemon
%service_add_pre atop.service atopacct.service

%post daemon
%service_add_post atop.service atopacct.service

%postun daemon
%service_del_postun atop.service atopacct.service

%preun daemon
%service_del_preun atop.service atopacct.service

%files
%defattr(-,root,root)
%doc COPYING README
%attr(0755,root,root) %{_bindir}/atop
%{_bindir}/atopsar
%{_bindir}/atop-%{pkg_version}
%{_bindir}/atopsar-%{pkg_version}
%doc %{_mandir}/man1/atop.1*
%doc %{_mandir}/man1/atopsar.1*
%doc %{_mandir}/man5/atoprc.5*
%{_datadir}/applications/%{name}.desktop

%files daemon
%defattr(-,root,root)
%doc COPYING README
%attr(0700,root,root) %dir %{_sysconfdir}/atop
%attr(0700,root,root) %{_sysconfdir}/atop/atop.daily
%config(noreplace) /etc/logrotate.d/psaccs_atop
%config(noreplace) /etc/logrotate.d/psaccu_atop
%config(noreplace) /etc/cron.d/%{name}
%{_localstatedir}/log/atop
%{_usr}/lib/systemd/system/%{name}.service
%doc %{_mandir}/man8/atopacctd.8*
%{_usr}/lib/systemd/system/atopacct.service
%dir %{_usr}/lib/systemd/system-sleep
%{_usr}/lib/systemd/system-sleep/atop-pm.sh
%{_sbindir}/atopacctd
%{_sbindir}/rcatopacct
%{_sbindir}/rc%{name}

%changelog
* Tue Nov 22 2016 coolo@suse.com
- update to 2.2:
  * Modifications for atop:
    a. New keys for process selection:
    '/' to select processes containing a particular search string in the command line arguments.
    'I' to select processes running with particular PIDs.
    b. New counters for NFS activity:
    On system level, counters are maintained about NFS traffic. Three new labels are introduced for this purpose:
    'NFS' for NFS server statistics (overall).
    'NFC' for NFS client statistics (overall).
    'NFM' for NFS client statistics per mounted NFS filesystem (so multiple lines possible).
    c. New counters for OpenVZ containers:
    CPU consumption and memory occupation are shown per container on system level (label 'CON').
    Container ID and virtual PID are shown on process level (when using key 'v' or 's').
    d. Bug fixes:
    The maximum transfer rate larger than 1 Gbit for ethernet interfaces is now correctly shown.
    The maximum transfer rate for wifi connections is now shown.
    For interfaces in general, the maximum transfer rate is shown as a separate column ('sp').
    Counters about virtual disk type 'xvd[a-z]' are shown.
    Several minor bugs have been solved.
  * Modifications for atopacct:
    a. Avoid that process accounting is reactivated too frequently (and unnecessary).
  * Modifications for atopsar:
    a. Add flags for NFS traffic ('-n' for NFS mounts, '-j' for overall NFS
    client activity and '-J' for overall NFS server activity).
  * General:
    a. Support for systemd-based distributions has been added.
    b. The format of the raw file is incompatible with earlier versions. However,
    the earlier version of atop is automatically activated when accessing an
    older raw file.
- cleanup spec file - remove support for < 12.1
* Sat Oct 18 2014 pascal.bleser@opensuse.org
- update to 2.1:
  * OpenVZ support: virtual environment identifier per process (envID)
  * Bug solution: when the screen-width is larger than the total number of
    columns to be printed, empty columns are added, however one column too many
  * Removed useless empty column for memory statistics
  * Introduce the 'G' key to suppress showing/accumulating exited processes
    in the output
  * Support CPU frequencies for systems with Intel P-state driver
  * Introduction of new daemon atopacctd. This daemon switches on process
    accounting and transfers every accounting record to an accounting shadow
    file. The source accounting file will regularly be truncated, while the
    shadow files are written with a limited size in a queued way. Non-used
    shadow files are deleted regularly.
  * Bug-solution: segmentation fault when one of the process names in the
    system contains a newline
  * Introduce configurable colors: in the atoprc file, colors can be defined
    for information messages (default green), threads (default yellow), almost
    critical resources (default cyan) and critical resources (default red).
  * Limit the names of network interfaces to six characters max
  * Introduction of proportional memory size (PSIZE) per process. For the
    resident memory parts used by a process that are shared with other
    processes, only a proportional part (shared memory part divided by the
    number of sharers) is accounted to the process. Since the gathering of this
    value is rather time-consuming (reading the smaps file of every process),
    it is optional ('R' key or '-R' flag).
  * Increased number of LVMs and disks supported
  * Support for huge pages (total and in use).
* Thu Jul 26 2012 pascal.bleser@opensuse.org
- update to 1.27-3:
  * service file for systemd
  * solved division-by-zero when maxfreq=0 and more precise coloring of
    concerning CPU-values when CPU overloaded
  * if setuid-root is set for atop, root-privileges are regained when reading
    /proc/pid/io (nowadays only readable for root) to obtain the disk stats per
    process
  * added EMC Power device recognition
  * better recognition of version of process accounting file
  * improved error handling when not enough columns or lines
  * suppress sorting of system resources by key F or flag -F (toggle)
  * create unique /tmp name for decompressed raw file
  * numerous cosmetic changes and man-page updates
  * improved screen handling
  * limited maximum file-size for process accounting file (200 MiB)
  * improved handling of process accounting
  * new key 'S' to make selections of system resources like logical volumes,
    disks and network interfaces (regular expression)
  * use of arrow-keys and PgUp/PgDown for vertical scroll
  * use of -> and <- keys for horizontal scroll of command line
  * support statistics for virtio disks (vd*)
  * fetching and displaying of individual threads
  * add various details about the memory usage of processes, like stack size,
    data size, shared library size and size used on swap
  * show new value about swap space usage per process
  * colors are shown now for separate system-level counters instead of for the
    entire line with counters
  * enhanced security: improved dropping of root privileges
* Mon Jan  9 2012 pascal.bleser@opensuse.org
- remove licenses package mumbo-jumbo altogether
- use pristine upstream tarball instead of recompressing as bz2
- added Recommends for logrotate and cron in the -daemon subpackage
* Mon Jan  9 2012 graham@andtech.eu
- change License: and %%if statement in .spec
* Tue Mar 15 2011 pascal.bleser@opensuse.org
- update to 1.26:
  * an additional value is shown for the current frequency and the current
    scaling percentage of the CPU
  * additional system-level counters are shown for the total number of threads
    that are running, sleeping interruptible, and sleeping uninterruptible
  * when the number of lines in a window is too small for the amount of
    system-level lines, the number of variable resources (like disks,
    interfaces, etc.) is limited automatically to be able to continue
  * the signal SIGUSR2 can be sent to atop to take one more sample and
    terminate (e.g. used to speed up suspend/hibernate)
  * support for the disk type 'mmcblk'
* Mon May  3 2010 pascal.bleser@opensuse.org
- update to 1.25:
  * disk I/O statistics are maintained on level of logical volume
    (LVM) and MD device
  * log files are properly switched in case of suspend/hibernate
  * layout of lines with system-level statistics can be redefined
  * previous atop versions are automatically activated for older
    log files
* Tue Jan 26 2010 pascal.bleser@opensuse.org
- update to 1.24:
  * the screen interface has been redesigned completely with
    support for a variable number of columns depending on the
    window size
  * it is now possible to define your own output line with
    process-level statistics
  * a system-wide configuration file was introduced for atop and
    atopsar
  * handling of log files was improved and additional counters are
    maintained
* Thu Mar  6 2008 guru@unixtech.be
- update to 1.23
* Wed Nov 21 2007 guru@unixtech.be
- update to 1.22
* Mon Aug 20 2007 guru@unixtech.be
- update to 1.21
* Mon Jun 11 2007 guru@unixtech.be
- inital openSUSE Build Service submission
